@@ -164,7 +164,6 @@ class MultiTool(object):
         wanted = argv[0]
         p = NamespacedOptionParser(argv[1:])
         for name, worker, _ in multi_args(p, cmd):
-            print("NAME: %s WANTED: %s" % (name, wanted))
             if name == wanted:
                 print(" ".join(worker))
                 return
@@ -225,11 +224,14 @@ class MultiTool(object):
                 callback(*node)
 
         self.note(self.colored.blue("> Stopping nodes..."))
-        for node in P:
-            nodename, _, pid = node
-            self.note("\t> %s: %s -> %s" % (nodename, SIGMAP[sig][3:], pid))
-            if not self.signal_node(nodename, pid, sig):
-                on_down(node)
+        for node in list(P):
+            if node in P:
+                nodename, _, pid = node
+                self.note("\t> %s: %s -> %s" % (nodename,
+                                                SIGMAP[sig][3:],
+                                                pid))
+                if not self.signal_node(nodename, pid, sig):
+                    on_down(node)
 
         def note_waiting():
             left = len(P)
