@@ -66,6 +66,7 @@ _DEFAULTS = {
     "CELERYD_LOG_COLOR": False,
     "CELERYD_LOG_LEVEL": "WARN",
     "CELERYD_LOG_FILE": None,                       # stderr
+    "CELERYD_HIJACK_ROOT_LOGGER": True,
     "CELERYBEAT_SCHEDULER": "celery.beat.PersistentScheduler",
     "CELERYBEAT_SCHEDULE": {},
     "CELERYD_STATE_DB": None,
@@ -97,6 +98,7 @@ _DEFAULTS = {
     "SERVER_EMAIL": "celery@localhost",
     "EMAIL_HOST": "localhost",
     "EMAIL_PORT": 25,
+    "EMAIL_TIMEOUT": 2,
     "ADMINS": (),
 }
 
@@ -184,6 +186,7 @@ def prepare(m, source=settings, defaults=_DEFAULTS):
                             compat=["CELERYD_DAEMON_LOG_LEVEL"])
     if not isinstance(m.CELERYD_LOG_LEVEL, int):
         m.CELERYD_LOG_LEVEL = LOG_LEVELS[m.CELERYD_LOG_LEVEL.upper()]
+    m.CELERYD_HIJACK_ROOT_LOGGER = _get("CELERYD_HIJACK_ROOT_LOGGER")
     m.CELERYD_STATE_DB = _get("CELERYD_STATE_DB")
     m.CELERYD_CONCURRENCY = _get("CELERYD_CONCURRENCY")
     m.CELERYD_PREFETCH_MULTIPLIER = _get("CELERYD_PREFETCH_MULTIPLIER")
