@@ -1,18 +1,16 @@
 import os
-import sys
 import warnings
 from importlib import import_module
 
 from celery.loaders.base import BaseLoader
+from celery.datastructures import AttributeDict
+from celery.exceptions import NotConfigured
 
 DEFAULT_CONFIG_MODULE = "celeryconfig"
 
 DEFAULT_SETTINGS = {
     "DEBUG": False,
     "ADMINS": (),
-    "DATABASE_ENGINE": "sqlite3",
-    "DATABASE_NAME": "celery.sqlite",
-    "INSTALLED_APPS": ("celery", ),
     "CELERY_IMPORTS": (),
     "CELERY_TASK_ERROR_WHITELIST": (),
 }
@@ -22,26 +20,10 @@ DEFAULT_UNCONFIGURED_SETTINGS = {
 }
 
 
-class NotConfigured(UserWarning):
-    """Celery has not been configured, as no config module has been found."""
-
-
 def wanted_module_item(item):
     return not item.startswith("_")
 
 
-class Settings(dict):
-
-    def __getattr__(self, key):
-        try:
-            return self[key]
-        except KeyError:
-            raise AttributeError(key)
-
-    def __setattr_(self, key, value):
-        self[key] = value
-
-
 class Loader(BaseLoader):
     """The default loader.
 
@@ -50,10 +32,7 @@ class Loader(BaseLoader):
     """
 
     def setup_settings(self, settingsdict):
-        settings = Settings(DEFAULT_SETTINGS, **settingsdict)
-        installed_apps = set(list(DEFAULT_SETTINGS["INSTALLED_APPS"]) + \
-                             list(settings.INSTALLED_APPS))
-        settings.INSTALLED_APPS = tuple(installed_apps)
+        settings = AttributeDict(DEFAULT_SETTINGS, **settingsdict)
         settings.CELERY_TASK_ERROR_WHITELIST = tuple(
                 getattr(import_module(mod), cls)
                     for fqn in settings.CELERY_TASK_ERROR_WHITELIST
@@ -61,25 +40,6 @@ class Loader(BaseLoader):
 
         return settings
 
-    def import_from_cwd(self, module, imp=import_module):
-        """Import module, but make sure it finds modules
-        located in the current directory.
-
-        Modules located in the current directory has
-        precedence over modules located in ``sys.path``.
-        """
-        cwd = os.getcwd()
-        if cwd in sys.path:
-            return imp(module)
-        sys.path.insert(0, cwd)
-        try:
-            return imp(module)
-        finally:
-            try:
-                sys.path.remove(cwd)
-            except ValueError:
-                pass
-
     def read_configuration(self):
         """Read configuration from ``celeryconfig.py`` and configure
         celery and Django so it can be used by regular Python."""
@@ -103,8 +63,8 @@ class Loader(BaseLoader):
         """Imports modules at worker init so tasks can be registered
         and used by the worked.
 
-        The list of modules to import is taken from the ``CELERY_IMPORTS``
-        setting in ``celeryconf.py``.
+        The list of modules to import is taken from the
+        :setting:`CELERY_IMPORTS` setting.
 
         """
         self.import_default_modules()
