@@ -7,6 +7,7 @@ config = os.environ.setdefault("CELERY_TEST_CONFIG_MODULE",
 
 os.environ["CELERY_CONFIG_MODULE"] = config
 os.environ["CELERY_LOADER"] = "default"
+os.environ["TIMER2_TRACE_THREAD"] = "yes"
 
 
 def teardown():
@@ -23,3 +24,11 @@ def teardown():
         sys.stderr.write(
             "\n\n**WARNING**: Remaning threads at teardown: %r...\n" % (
                 remaining_threads))
+        for thread in remaining_threads:
+            try:
+                started_by = thread._started_by[thread.ident]
+            except (AttributeError, KeyError):
+                pass
+            else:
+                sys.stderr.write("THREAD %r STARTED BY:\n%r\n" % (
+                    thread, started_by))
