@@ -7,8 +7,6 @@ from celery.concurrency import processes as mp
 from celery.datastructures import ExceptionInfo
 from celery.utils import noop
 
-from celery.tests.utils import skip_if_quick
-
 
 class Object(object):   # for writeable attributes.
 
@@ -176,13 +174,3 @@ class test_TaskPool(unittest.TestCase):
         info = pool.info
         self.assertEqual(info["max-concurrency"], pool.limit)
         self.assertEqual(len(info["processes"]), pool.limit)
-
-    @skip_if_quick
-    def test_diagnose(self):
-        pool = ExeMockTaskPool(10)
-        pool.start()
-
-        r = pool.diagnose(timeout=None)
-        self.assertEqual(len(r["active"]), pool.limit)
-        self.assertFalse(r["waiting"])
-        self.assertTrue(r["iterations"])
