@@ -1,6 +1,6 @@
 import unittest2 as unittest
 
-from billiard.serialization import pickle
+from celery.serialization import pickle
 
 
 class RegularException(Exception):
