@@ -3,11 +3,14 @@
 Worker Controller Threads
 
 """
+import logging
+import sys
 import threading
 import traceback
 from Queue import Empty as QueueEmpty
 
 from celery import log
+from celery.utils.compat import log_with_extra
 
 
 class Mediator(threading.Thread):
@@ -51,8 +54,13 @@ class Mediator(threading.Thread):
         try:
             self.callback(task)
         except Exception, exc:
-            self.logger.error("Mediator callback raised exception %r\n%s" % (
-                exc, traceback.format_exc()))
+            log_with_extra(self.logger, logging.ERROR,
+                           "Mediator callback raised exception %r\n%s" % (
+                               exc, traceback.format_exc()),
+                           exc_info=sys.exc_info(),
+                           extra={"data": {"hostname": task.hostname,
+                                           "id": task.task_id,
+                                           "name": task.task_name}})
 
     def run(self):
         while not self._shutdown.isSet():
