@@ -77,6 +77,7 @@ from __future__ import generators
 
 import socket
 import sys
+import traceback
 import warnings
 
 from carrot.connection import AMQPConnectionException
@@ -208,6 +209,7 @@ class CarrotListener(object):
             initial_prefetch_count=2, pool=None):
         self.connection = None
         self.task_consumer = None
+        self.broadcast_consumer = None
         self.ready_queue = ready_queue
         self.eta_schedule = eta_schedule
         self.send_events = send_events
@@ -236,7 +238,7 @@ class CarrotListener(object):
             self.reset_connection()
             try:
                 self.consume_messages()
-            except (socket.error, AMQPConnectionException, IOError):
+            except (socket.error, AMQPConnectionException, IOError, OSError):
                 self.logger.error("CarrotListener: Connection to broker lost."
                                 + " Trying to re-establish connection...")
 
@@ -292,15 +294,28 @@ class CarrotListener(object):
 
     def on_control(self, control):
         """Handle received remote control command."""
-        return self.control_dispatch.dispatch_from_message(control)
+        try:
+            self.control_dispatch.dispatch_from_message(control)
+        except Exception, exc:
+            self.logger.error(
+                "Error occurred while handling control command: %r\n%s" % (
+                    exc, traceback.format_exc()))
 
     def receive_message(self, message_data, message):
         """The callback called when a new message is received. """
 
         # Handle task
         if message_data.get("task"):
+            def ack():
+                try:
+                    message.ack()
+                except (socket.error, AMQPConnectionException,
+                        IOError, OSError), exc:
+                    self.logger.critical(
+                            "Couldn't ack %r: message:%r reason:%r" % (
+                                message.delivery_tag, message_data, exc))
             try:
-                task = TaskRequest.from_message(message, message_data,
+                task = TaskRequest.from_message(message, message_data, ack,
                                                 logger=self.logger,
                                                 hostname=self.hostname,
                                                 eventer=self.event_dispatcher)
@@ -340,6 +355,12 @@ class CarrotListener(object):
                     self.maybe_conn_error(self.task_consumer.close)
         self.logger.debug("CarrotListener: "
                           "Closing connection to broker...")
+
+        self.logger.debug("CarrotListener: Closing broadcast channel...")
+        if self.broadcast_consumer:
+            self.broadcast_consumer = \
+                    self.maybe_conn_error(self.broadcast_consumer.close)
+
         if self.connection:
             self.connection = self.maybe_conn_error(self.connection.close)
 
@@ -362,6 +383,10 @@ class CarrotListener(object):
             self.event_dispatcher = \
                     self.maybe_conn_error(self.event_dispatcher.close)
 
+        self.logger.debug("BroadcastConsumer: Cancelling consumer...")
+        if self.broadcast_consumer:
+            self.maybe_conn_error(self.broadcast_consumer.cancel)
+
         if close:
             self.close_connection()
 
@@ -391,12 +416,12 @@ class CarrotListener(object):
         self.connection = self._open_connection()
         self.logger.debug("CarrotListener: Connection Established.")
         self.task_consumer = get_consumer_set(connection=self.connection)
+        self.task_consumer.on_decode_error = self.on_decode_error
         # QoS: Reset prefetch window.
         self.qos = QoS(self.task_consumer,
                        self.initial_prefetch_count, self.logger)
         self.qos.update()                       # enable prefetch_count QoS.
 
-        self.task_consumer.on_decode_error = self.on_decode_error
         self.broadcast_consumer = BroadcastConsumer(self.connection,
                                                     hostname=self.hostname)
         self.task_consumer.register_callback(self.receive_message)
